@@ -1,5 +1,9 @@
 import re
 import logging
+import tempfile
+from pathlib import Path
+from pyrpm.spec import Spec
+import git
 import requests
 from bs4 import BeautifulSoup
 import traceback
@@ -131,10 +135,81 @@ class Gitee():
                 log.error(f"request url is {url}, parameters is {parameters},headers is {headers} failed, response status code is {response.status_code}")
                 break
 
+
+DEFAULT_MACROS = {
+    "python3_pkgversion": '3.9',
+    "lustre_name":"lustre"
+}
+
 class OpenEuler():
     def __init__(self):
         pass
 
+    def __replace_macros(self,value, macros):
+        """根据宏字典替换字符串中的宏."""
+        original_value = value
+        while True:
+            for key, val in macros.items():
+                value = re.sub(r'%\{' + re.escape(key) + r'\}', val, value)
+            if value == original_value:
+                break
+            original_value = value
+        return value
+
+    def __extract_macros(self,spec):
+        macros = {}
+        for key, value in spec.macros.items():
+            macros[key] = value
+        if "name" not in macros.keys():
+            macros['name'] = spec.name
+        if "version" not in macros.keys():
+            macros['version'] = spec.version
+        if "release" not in macros.keys():
+            macros['release'] = spec.release
+        for k, w in DEFAULT_MACROS.items():
+            if k not in macros.keys():
+                macros[k] = w
+        return macros
+
+    def __get_spec_files(self,root_path):
+        spec_files = []
+        for elem in Path(root_path).glob("**/*"):
+            if Path(elem).is_file() and elem.name.endswith(".spec"):
+                spec_files.append(elem)
+        return spec_files
+
+    def __get_rpm_list_from_spec(self,spec_file):
+        """从 RPM spec 文件中提取所有包名并替换宏。"""
+        spec = Spec.from_file(spec_file)
+        rpm_list = []
+        macros = self.__extract_macros(spec)
+
+        # 提取子包名称
+        for pkg in spec.packages:
+            subpackage_name = self.__replace_macros(pkg.name, macros)
+            if subpackage_name not in rpm_list:
+                if "%" in subpackage_name:
+                    log.warning(f"{subpackage_name} contains macro, please check")
+                else:
+                    rpm_list.append(subpackage_name)
+
+        return rpm_list
+
+    def get_openEuler_rpm_names_from_repo(self,os_version,repo_name,repo_url):
+        branch=f"openEuler-{os_version}"
+        rpm_list = []
+        with tempfile.TemporaryDirectory() as temp_dir:
+            git.Repo.clone_from(repo_url, temp_dir, branch=branch, depth=1)
+            log.info(f"clone {repo_name} success")
+            spec_files = self.__get_spec_files(temp_dir)
+
+            for spec_file in spec_files:
+                temp_list = self.__get_rpm_list_from_spec(spec_file)
+                for elem in temp_list:
+                    if elem not in rpm_list:
+                        rpm_list.append(elem)
+        return rpm_list
+
     def get_openEuler_repo_names_and_urls(
             self,
             os_version: str
@@ -244,7 +319,9 @@ class OpenEuler():
 
 if __name__ == "__main__":
     # 初始化获取器
-    # oe = OpenEuler()
+    oe = OpenEuler()
+    for rpm in oe.get_openEuler_rpm_names_from_repo("24.03-LTS-SP2", "python-minio","https://gitee.com/src-openeuler/python-minio.git"):
+        print(f"src_name:python-minio,rpm:{rpm}")
     # log.info("正在初始化 Gitee 模块...")
     # repos_generator = oe.get_openEuler_repo_names_and_urls(
     #     os_version="24.03-LTS-SP2"
